@@ -9,13 +9,18 @@ class Git(object):
     self.index = self.repo.index
     self.remote = getattr(self.repo.remotes, remote)
 
-  def commit(self, objects, message):
+  def commit(self, objects, message, action='add'):
     # validate commit message
     if not message or not isinstance(message, basestring):
       raise ValueError("Commit message should not be empty or not string")
 
     # create the commit
-    self.index.add(objects)
+    if action == 'add':
+      self.index.add(objects)
+
+    if action == 'remove':
+      self.index.remove(objects)
+
     self.index.commit(message)
 
     # fetch, pull and push from and to the remote
